@@ -2,7 +2,7 @@ package Web::Hippie;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 use parent 'Plack::Middleware';
 
 use Plack::Util::Accessor qw( root init on_error on_message trusted_origin );
@@ -181,8 +181,8 @@ sub handler_ws {
 
             use Web::Hippie::Handle::WebSocket;
             $env->{'hippie.handle'} = Web::Hippie::Handle::WebSocket->new
-                ( id => $client_id,
-                  h  => $h );
+                ({ id => $client_id,
+                   h  => $h });
             $h->on_error( $self->connection_cleanup($env, $handler, $h) );
 
             my @keys = map {
